[cvs-annodex] commit (/annodex): cmmlwiki/trunk/cmmlwiki/framer.py

j nobody at lists.annodex.net
Sun Dec 4 08:41:54 EST 2005


Update of /annodex (new revision 1673)

Modified files:
   cmmlwiki/trunk/cmmlwiki/framer.py

Log Message:
switch to gst 0.10

Modified: cmmlwiki/trunk/cmmlwiki/framer.py
===================================================================
--- cmmlwiki/trunk/cmmlwiki/framer.py	2005-12-02 05:33:42 UTC (rev 1672)
+++ cmmlwiki/trunk/cmmlwiki/framer.py	2005-12-03 21:41:51 UTC (rev 1673)
@@ -21,7 +21,7 @@
 from cmmlwiki.utils import content_type
 from cmmlwiki.time import time2npt
 
 #as it depends on gst0.9 disabled for now
 #FIXME: does not return an image if seeking beond eof
 use_gst=False
 
@@ -32,7 +32,7 @@
         global Image, pygst, gst
         import Image
         import pygst
-        pygst.require('0.9')
+        pygst.require('0.10')
         import gst
 
         self.png_frame = png_frame
@@ -21,7 +21,7 @@
 from cmmlwiki.time import time2npt
 
-#as it depends on gst0.9 disabled for now
+#as it depends on gst0.10 disabled for now
 #FIXME: does not return an image if seeking beond eof
 use_gst=False


-- 
j



More information about the cvs-annodex mailing list